![logo](../.docs/logo_themes.svg)

## Themes available

|    **Name**      |    **Flavors**     |  **Light** | **Dark** | **C4** |  **Card**  |
|:----------:|:--------------:|:-----:|:-----:|:------:|:-----------------------:|
|    `default`     | <ul><li>`light`</li><li>`dark`</li></ul> | ✅ | ✅ | ✅ | [**themes/default**](default/README.md) |
| `catppuccin` | <ul><li>`latte`</li><li>`latte-white`</li><li>`frappe`</li><li>`macchiato`</li><li>`mocha`</li></ul> | ✅ | ✅ | ✅ | [**themes/catppuccin**](catppuccin/README.md)|

## Contribute theme

We welcome theme contributors to this project! Whether you have a creative idea
or want to implement a popular color palette for PlantUML,
we encourage you to get involved and share your work with the community.
Follow the guide below to add your theme or update existing one in the repository.

**TODO**: write guide.
